@@ -239,14 +239,14 @@ plot.mqcc <- function(x, add.stats = TRUE, chart.all = TRUE,
                                    "and", newdata.name)
             else main.title <- paste(type, "Chart\nfor", newdata.name) }
   else main.title <- paste(title)
-  #
-  oldpar <- par(bg  = qcc.options("bg.margin"), 
-                cex = qcc.options("cex"),
-                mar = if(add.stats)
-                           pmax(par("mar"), c(8.5,0,0,0))
-                      else par("mar"),
-                no.readonly = TRUE)
+
+  oldpar <- par(no.readonly = TRUE)
   if(restore.par) on.exit(par(oldpar))
+  mar <- pmax(oldpar$mar, c(5.1,4.1,4.1,2.1))
+  par(bg  = qcc.options("bg.margin"), 
+      cex = qcc.options("cex"),
+      mar = if(add.stats) pmax(mar, c(8.5,0,0,0)) else mar)
+
   # plot Shewhart chart
   plot(indices, statistics, type = "n",
        ylim = if(!missing(ylim)) ylim 
